.userrole-authenticated {
    .r-search-container {
        padding: 0 20px 0 123px;
    }
}

.r-search-container {
    max-width: 1330px;
    margin: 0 auto;
    padding: 0 20px 0 20px;

    .full-width {
        width: 100vw;
        position: relative;
        left: 50%;
        right: 50%;
        margin-left: -50vw;
        margin-right: -50vw;
    }

    .r-search-highlighter {
        padding: 0;
        font-weight: bold;
        background: transparent;
        position: relative;
        border-bottom: 2px solid #f9b300;
    }

    .r-search-header {
        border-bottom: 1px solid #000;
    }

    .r-search-header-title {
        font-weight: bold;
        font-size: 15px;
        text-transform: uppercase;
    }

    .r-search-header-count {
        font-size: 10px;
        text-transform: uppercase;
        color: #808080;
    }

    .r-search-result {
        margin-top: 2rem;
        display: grid;
        grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
        gap: 1.5rem;
    }

    .r-search.search-bar-filter {
        position: relative;

        form {
            position: relative;
        }

        label,
        input {
            width: 100%;
        }

        input {
            line-height: 50px;
            border: 1px solid #cccccc;
            height: 50px;
            padding: 0 10px;
            font-weight: bold;
            color: #000;
            letter-spacing: 1.2px;

            &::placeholder {
                color: #000;
                font-size: 12px;
                opacity: 1;
                text-transform: uppercase;
                letter-spacing: 1.2px;
            }
        }

        button {
            background: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'%3E%3Cg id='Calque_2' data-name='Calque 2'%3E%3Cg id='Calque_1-2' data-name='Calque 1'%3E%3Cg id='search'%3E%3Cpath id='Shape' d='M11.08,6.77a4.31,4.31,0,1,0-4.31,4.31h0A4.32,4.32,0,0,0,11.08,6.77Zm4.92,8A1.24,1.24,0,0,1,14.77,16a1.17,1.17,0,0,1-.86-.37l-3.3-3.28a6.77,6.77,0,1,1,1.74-1.74l3.3,3.3A1.25,1.25,0,0,1,16,14.77Z' style='fill:%23141414;fill-rule:evenodd'/%3E%3C/g%3E%3C/g%3E%3C/g%3E%3C/svg%3E")
                no-repeat;
            background-position: center;
            background-size: 80%;
            border: none;
            width: 20px;
            position: absolute;
            right: 10px;
            top: 0;
            bottom: 0;
        }
    }

    .r-search-select {
        height: 50px;
        border-radius: 0px;
    }

    .r-search-list {
        margin-top: 20px;
        overflow-y: scroll;

        @media screen and (min-width: 992px) {
            max-height: 375px;
        }

        .r-search-item {
            list-style: none;
            border-bottom: 1px solid rgba(0, 0, 0, 0.25);
            padding: 1rem 0;
            font-size: 14px;
            display: flex;
            gap: 10px;

            .r-search-img {
                width: 91px;
                height: 61px;
                background-size: cover;
                background-repeat: no-repeat;
                flex-basis: 100%;
                flex-basis: 91px;
                flex-grow: 0;
                flex-shrink: 0;
            }
        }
    }
}

.offcanvas-header .btn-close {
    right: 10px;
    position: absolute;
    top: 10px;
}

.search-contact .r-search-img,
.search-events .r-search-img,
.search-news .r-search-img {
    float: left;
    margin-right: 0.5rem;
}

.r-search-result mark {
    display: initial;
}
